==> xmms-singit_0.1.27.orig.tar.gz: xmms-singit-0.1.27/src/tagger/list_genres.h <==
/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __LIST_GENRES_H__
#define __LIST_GENRES_H__

#include "singit_macros.h"

#define list_genres_count 148
static const char *list_genres[] = {
	N_("(unknown)"),
	N_("Blues"),
	N_("Classic Rock"),
	N_("Country"),
	N_("Dance"),
	N_("Disco"),
	N_("Funk"),
	N_("Grunge"),
	N_("Hip-Hop"),
	N_("Jazz"),
	N_("Metal"),
	N_("New Age"),
	N_("Oldies"),
	N_("Other"),
	N_("Pop"),
	N_("R&B"),
	N_("Rap"),
	N_("Reggae"),
	N_("Rock"),
	N_("Techno"),
	N_("Industrial"),
	N_("Alternative"),
	N_("Ska"),
	N_("Death Metal"),
	N_("Pranks"),
	N_("Soundtrack"),
	N_("Euro-Techno"),
	N_("Ambient"),
	N_("Trip-Hop"),
	N_("Vocal"),
	N_("Jazz+Funk"),
	N_("Fusion"),
	N_("Trance"),
	N_("Classical"),
	N_("Instrumental"),
	N_("Acid"),
	N_("House"),
	N_("Game"),
	N_("Sound Clip"),
	N_("Gospel"),
	N_("Noise"),
	N_("Alt. Rock"), // N_("Alt"),
	N_("Bass"),
	N_("Soul"),
	N_("Punk"),
	N_("Space"),
	N_("Meditative"),
	N_("Instrum. Pop"), // N_("Instrumental Pop"),
	N_("Instrum. Rock"), // N_("Instrumental Rock"),
	N_("Ethnic"),
	N_("Gothic"),
	N_("Darkwave"),
	N_("Techno-Indust."), // N_("Techno-Industrial"),
	N_("Electronic"),
	N_("Pop-Folk"),
	N_("Eurodance"),
	N_("Dream"),
	N_("Southern Rock"),
	N_("Comedy"),
	N_("Cult"),
	N_("Gangsta"), // N_("Gangsta Rap"),
	N_("Top 40"),
	N_("Christian Rap"),
	N_("Pop/Funk"),
	N_("Jungle"),
	N_("Native American"),
	N_("Cabaret"),
	N_("New Wave"),
	N_("Psychedelic"),
	N_("Rave"),
	N_("Showtunes"),
	N_("Trailer"),
	N_("Lo-Fi"),
	N_("Tribal"),
	N_("Acid Punk"),
	N_("Acid Jazz"),
	N_("Polka"),
	N_("Retro"),
	N_("Musical"),
	N_("Rock & Roll"),
	N_("Hard Rock"),
	N_("Folk"),
	N_("Folk/Rock"),
	N_("National Folk"),
	N_("Swing"),
	N_("Fusion"), // N_("Fast-Fusion"),
	N_("Bebob"),
	N_("Latin"),
	N_("Revival"),
	N_("Celtic"),
	N_("Bluegrass"),
	N_("Avantgarde"),
	N_("Gothic Rock"),
	N_("Progress. Rock"), // N_("Progressive Rock"),
	N_("Psychadel. Rock"), // N_("Psychedelic Rock"),
	N_("Symphonic Rock"),
	N_("Slow Rock"),
	N_("Big Band"),
	N_("Chorus"),
	N_("Easy Listening"),
	N_("Acoustic"),
	N_("Humour"),
	N_("Speech"),
	N_("Chanson"),
	N_("Opera"),
	N_("Chamber Music"),
	N_("Sonata"),
	N_("Symphony"),
	N_("Booty Bass"),
	N_("Primus"),
	N_("Porn Groove"),
	N_("Satire"),
/*
 *  The following were added 1999 26 Apr by Ben Gertzfield <che@debian.org>
 *  as per the list at http://mp3.musichall.cz/id3master/faq.htm but with a
 *  few spell-checks confirmed by running 'strings' on the in_mp3.dll file
 *  from winamp 2.10 (sorry :)
 */
	N_("Slow Jam"),
	N_("Club"),
	N_("Tango"),
	N_("Samba"),
	N_("Folklore"),
	N_("Ballad"),
	N_("Power Ballad"),
	N_("Rhythmic Soul"),
	N_("Freestyle"),
	N_("Duet"),
	N_("Punk Rock"),
	N_("Drum Solo"),
	N_("A Cappella"),
	N_("Euro-House"),
	N_("Dance Hall"),
	N_("Goa"),
	N_("Drum & Bass"),
	N_("Club-House"),
	N_("Hardcore"),
	N_("Terror"),
	N_("Indie"),
	N_("BritPop"),
	N_("Negerpunk"),
	N_("Polsk Punk"),
	N_("Beat"),

/*  DJ JC in da house  */
	N_("Christian Gangsta Rap"),
	N_("Heavy Metal"),
	N_("Black Metal"),
	N_("Crossover"),
	N_("Contemporary Christian"),
	N_("Christian Rock"),

/*  WinAmp 1.91 genres  */
	N_("Merengue"),
	N_("Salsa"),
	N_("Thrash Metal"),

/*  WinAmp 1.92 genres  */
	N_("Anime"),
	N_("JPop"),
	N_("Synthpop"),
	NULL
};

#endif // __LIST_GENRES_H__

==> xmms-singit_0.1.28.orig.tar.gz: xmms-singit-0.1.28.orig/src/tagger/list_genres.h <==
/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __LIST_GENRES_H__
#define __LIST_GENRES_H__

#include "singit/macros.h"

#define list_genres_count 148
static const char *list_genres[] = {
	N_("(unknown)"),
	N_("Blues"),
	N_("Classic Rock"),
	N_("Country"),
	N_("Dance"),
	N_("Disco"),
	N_("Funk"),
	N_("Grunge"),
	N_("Hip-Hop"),
	N_("Jazz"),
	N_("Metal"),
	N_("New Age"),
	N_("Oldies"),
	N_("Other"),
	N_("Pop"),
	N_("R&B"),
	N_("Rap"),
	N_("Reggae"),
	N_("Rock"),
	N_("Techno"),
	N_("Industrial"),
	N_("Alternative"),
	N_("Ska"),
	N_("Death Metal"),
	N_("Pranks"),
	N_("Soundtrack"),
	N_("Euro-Techno"),
	N_("Ambient"),
	N_("Trip-Hop"),
	N_("Vocal"),
	N_("Jazz+Funk"),
	N_("Fusion"),
	N_("Trance"),
	N_("Classical"),
	N_("Instrumental"),
	N_("Acid"),
	N_("House"),
	N_("Game"),
	N_("Sound Clip"),
	N_("Gospel"),
	N_("Noise"),
	N_("Alt. Rock"), // N_("Alt"),
	N_("Bass"),
	N_("Soul"),
	N_("Punk"),
	N_("Space"),
	N_("Meditative"),
	N_("Instrum. Pop"), // N_("Instrumental Pop"),
	N_("Instrum. Rock"), // N_("Instrumental Rock"),
	N_("Ethnic"),
	N_("Gothic"),
	N_("Darkwave"),
	N_("Techno-Indust."), // N_("Techno-Industrial"),
	N_("Electronic"),
	N_("Pop-Folk"),
	N_("Eurodance"),
	N_("Dream"),
	N_("Southern Rock"),
	N_("Comedy"),
	N_("Cult"),
	N_("Gangsta"), // N_("Gangsta Rap"),
	N_("Top 40"),
	N_("Christian Rap"),
	N_("Pop/Funk"),
	N_("Jungle"),
	N_("Native American"),
	N_("Cabaret"),
	N_("New Wave"),
	N_("Psychedelic"),
	N_("Rave"),
	N_("Showtunes"),
	N_("Trailer"),
	N_("Lo-Fi"),
	N_("Tribal"),
	N_("Acid Punk"),
	N_("Acid Jazz"),
	N_("Polka"),
	N_("Retro"),
	N_("Musical"),
	N_("Rock & Roll"),
	N_("Hard Rock"),
	N_("Folk"),
	N_("Folk/Rock"),
	N_("National Folk"),
	N_("Swing"),
	N_("Fusion"), // N_("Fast-Fusion"),
	N_("Bebob"),
	N_("Latin"),
	N_("Revival"),
	N_("Celtic"),
	N_("Bluegrass"),
	N_("Avantgarde"),
	N_("Gothic Rock"),
	N_("Progress. Rock"), // N_("Progressive Rock"),
	N_("Psychadel. Rock"), // N_("Psychedelic Rock"),
	N_("Symphonic Rock"),
	N_("Slow Rock"),
	N_("Big Band"),
	N_("Chorus"),
	N_("Easy Listening"),
	N_("Acoustic"),
	N_("Humour"),
	N_("Speech"),
	N_("Chanson"),
	N_("Opera"),
	N_("Chamber Music"),
	N_("Sonata"),
	N_("Symphony"),
	N_("Booty Bass"),
	N_("Primus"),
	N_("Porn Groove"),
	N_("Satire"),
/*
 *  The following were added 1999 26 Apr by Ben Gertzfield <che@debian.org>
 *  as per the list at http://mp3.musichall.cz/id3master/faq.htm but with a
 *  few spell-checks confirmed by running 'strings' on the in_mp3.dll file
 *  from winamp 2.10 (sorry :)
 */
	N_("Slow Jam"),
	N_("Club"),
	N_("Tango"),
	N_("Samba"),
	N_("Folklore"),
	N_("Ballad"),
	N_("Power Ballad"),
	N_("Rhythmic Soul"),
	N_("Freestyle"),
	N_("Duet"),
	N_("Punk Rock"),
	N_("Drum Solo"),
	N_("A Cappella"),
	N_("Euro-House"),
	N_("Dance Hall"),
	N_("Goa"),
	N_("Drum & Bass"),
	N_("Club-House"),
	N_("Hardcore"),
	N_("Terror"),
	N_("Indie"),
	N_("BritPop"),
	N_("Negerpunk"),
	N_("Polsk Punk"),
	N_("Beat"),

/*  DJ JC in da house  */
	N_("Christian Gangsta Rap"),
	N_("Heavy Metal"),
	N_("Black Metal"),
	N_("Crossover"),
	N_("Contemporary Christian"),
	N_("Christian Rock"),

/*  WinAmp 1.91 genres  */
	N_("Merengue"),
	N_("Salsa"),
	N_("Thrash Metal"),

/*  WinAmp 1.92 genres  */
	N_("Anime"),
	N_("JPop"),
	N_("Synthpop"),
	NULL
};

#endif // __LIST_GENRES_H__
